pub fn capture() -> (Host, Captured)Expand description
A Host whose messages are kept, for testing parts of a plugin (like a
crate::CallQueue) on their own.
pub fn capture() -> (Host, Captured)A Host whose messages are kept, for testing parts of a plugin (like a
crate::CallQueue) on their own.